#
# spec file for package python-http-parser
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-http-parser
Version:        0.9.0
Release:        2.2
Summary:        HTTP Request/Response Parser for Python in C
License:        MIT
URL:            https://github.com/benoitc/http-parser/
Source:         https://files.pythonhosted.org/packages/source/h/http-parser/http-parser-%{version}.tar.gz
# PATCH-FIX-UPSTREAM gh#benoitc/http-parser#101
Patch0:         remove-imp-module.patch
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%python_subpackages

%description
HTTP request/response parser for Python in C, based on
http-parser from Ryan Dahl.

%prep
%autosetup -p1 -n http-parser-%{version}

%build
# fix wrongly generated cyx files
find . -name '*.pyx' -exec cython {} \;
export CFLAGS="%{optflags} -fno-strict-aliasing"
%pyproject_wheel

%install
%pyproject_install
# Remove exec bits from example scripts
chmod a-x examples/*
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%files %{python_files}
%license LICENSE
%doc NOTICE README.rst examples
%{python_sitearch}/http_parser
%{python_sitearch}/http_parser-%{version}.dist-info

%changelog
* Thu Jan 11 2024 Steve Kowalik <steven.kowalik@suse.com>
- Switch to autosetup and pyproject macros.
- Stop using greedy globs in %%files.
- Actually run fdupes.
- Add patch remove-imp-module.patch:
  * Use importlib, not imp.
* Wed Jun 17 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.9.0:
  + No changelog available
* Wed Jan  2 2019 Tomáš Chvátal <tchvatal@suse.com>
- Regen cython code to fix an issue with python 3.7
* Fri Sep  1 2017 jengelh@inai.de
- Remove duplicated license metadata.
* Thu Aug 24 2017 jmatejek@suse.com
- singlespec auto-conversion
* Sun Dec  8 2013 p.drouand@gmail.com
- Update to version 0.8.3
  + No changelog availalbe
- Remove pre_checkin.sh; python3 packages moved to d:l:p3
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Tue Feb 26 2013 p.drouand@gmail.com
- Initial python3 support
* Sat Feb  9 2013 p.drouand@gmail.com
- Update to 0.8.1:
  * No changelog available
* Sat Oct  6 2012 os-dev@jacraig.com
- Update to 0.7.12:
  * fix __eq__
  * fix environ update
- Changes from 0.7.11:
  * api should be consistent
- Changes from 0.7.10:
  * Fixed pyparser.py to work on Python 3
  * Bugfix: match against upper-cased header names
  * Bugfix: looking for popped HTTP_SCRIPT_NAME
- Changes from 0.7.9:
  * Regenerated parser.c from Cython 0.17
  * Updated HTTP parser C code
  * use SocketIO object on python3
  * fix data type, fix iteration
- Remove unnecessary rm from %%install, those files no longer exist.
* Sun Sep  9 2012 os-dev@jacraig.com
- Update to 0.7.8:
  * fix python 3 compatibility
  * fix categories
  * fix requirements in the readme, add TODO
- Changes from 0.7.7:
  * fix setup
  * add an example: parse a response text file on windows
  * fix issue 14
- Changes from 0.7.6:
  * fix setup.py and rebuild the extension
  * remove support of py25
  * use setuptools to install http_parser
  * chech if self.environ exists before update it
  * add an example for parse windows response file
  * add PURGE method
  * rebuild code
  * sync http-parser C code from joyent
  * only create WSGI environ on demand
- Remove executable bits from example scripts (RPMLINT warning).
* Tue Feb 28 2012 jfunk@funktronics.ca
- Update to version 0.7.5:
  * fix whitespaces
  * multiple headers values should be separated by a ", " not ","
  * regenerate the C code
* Tue Jan 31 2012 saschpe@suse.de
- Update to version 0.7.4
* Wed Jan 25 2012 jfunk@funktronics.ca
- Update to version 0.7.2
* Sun Nov 27 2011 jfunk@funktronics.ca
- Update to version 0.7.1
* Fri Sep 23 2011 saschpe@suse.de
- Update to version 0.7.0
* Mon Jun 20 2011 jfunk@funktronics.ca
- Initital release
